@@ -55,7 +55,7 @@ CardArea::CardArea()
 
   SetCanFocus(true);
 
-  AttachModel(timerAction);
+  Observe(timerAction);
 }
 
 void CardArea::Unselect()
