@@ -43,8 +43,8 @@ ChooseMoveDialog::ChooseMoveDialog(const Card& card,
 {
   GetClosedAction()->Disable();
 
-  AttachModel(GetClosedAction());
-  AttachModel(selection);
+  Observe(GetClosedAction());
+  Observe(selection);
 }
 
 void ChooseMoveDialog::PreInit()
