@@ -36,10 +36,10 @@ GameStartDialog::GameStartDialog(size_t points, size_t player)
 {
   commitAction->Disable();
 
-  AttachModel(GetClosedAction());
+  Observe(GetClosedAction());
 
-  AttachModel(commitAction);
-  AttachModel(this->points);
+  Observe(commitAction);
+  Observe(this->points);
 }
 
 void GameStartDialog::PreInit()
