@@ -37,7 +37,7 @@ RoundResultDialog::RoundResultDialog(const std::vector<Result> result,
   this->globalPoints[0]=globalPoints[0];
   this->globalPoints[1]=globalPoints[1];
 
-  AttachModel(GetClosedAction());
+  Observe(GetClosedAction());
 }
 
 Lum::Text* RoundResultDialog::GetTableEntry(const std::wstring& string, bool bold)
