@@ -131,16 +131,16 @@ public:
     lastHumanMoveAction->Disable();
     lastComputerMoveAction->Disable();
 
-    AttachModel(GetOpenedAction());
+    Observe(GetOpenedAction());
 
-    AttachModel(newGameAction);
-    AttachModel(lastHumanMoveAction);
-    AttachModel(lastComputerMoveAction);
-    AttachModel(aboutAction);
+    Observe(newGameAction);
+    Observe(lastHumanMoveAction);
+    Observe(lastComputerMoveAction);
+    Observe(aboutAction);
 
-    AttachModel(handSelectionAction);
-    AttachModel(handFadedAction);
-    AttachModel(tableFadedAction);
+    Observe(handSelectionAction);
+    Observe(handFadedAction);
+    Observe(tableFadedAction);
 
     Lum::Base::Path path;
 
