@@ -36,7 +36,7 @@ ShowMoveDialog::ShowMoveDialog(bool playerIsComputer,
    move(move),
    images(images)
 {
-  AttachModel(GetClosedAction());
+  Observe(GetClosedAction());
 }
 
 void ShowMoveDialog::PreInit()
